@@ -268,8 +268,7 @@ def add_logo(logo_path, offsets=(0, 0), scale=0.25):
 
     # Updating string to directory path if using a supported logo
     if logo_path in supported_logos:
-        cwd = os.getcwd()
-        path = os.path.join(cwd, 'logos')
+        path = os.path.join(os.path.dirname(__file__), 'logos')
         logo_path = os.path.join(path, logo_path + '.png')
 
     try:
@@ -455,7 +454,7 @@ def import_roboto():
     '''
     Import the Roboto font and add it as the default font family
     '''
-    cwd = os.getcwd()
+    cwd = os.path.join(os.path.dirname(__file__), 'fonts')
     font_files = font_manager.findSystemFonts(fontpaths=cwd, fontext="ttf")
 
     for font_file in font_files:
